"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const src_1 = require("../src");
const commander_1 = require("commander");
const program = new commander_1.Command();
program
    .command('parse <query>')
    .option('-a, --allow-apex', 'allow apex bind variables')
    .option('-i, --ignore-errors', 'ignore parse errors, return as much of query as possible')
    .action((query, options) => {
    console.log(JSON.stringify(src_1.parseQuery(query, {
        allowApexBindVariables: options.allowApex,
        ignoreParseErrors: options.ignoreErrors,
    })));
});
program
    .command('compose <query>')
    .option('-f, --format', 'format output')
    .option('-i --indent <chars>', 'number of tab characters to indent', 1)
    .option('-m --line-length <chars>', 'max number of characters per lins', 60)
    .option('-s --subquery-parens-new-line', 'subquery parens on own line')
    .option('-k --keywords-new-line', 'new line after keywords')
    .option('-j, --json', 'output as JSON')
    .action((query, options) => {
    const formatOptions = {};
    if (options.indent) {
        formatOptions.numIndent = options.indent;
    }
    if (options.lineLength) {
        formatOptions.fieldMaxLineLength = options.lineLength;
    }
    if (options.subqueryParensNewLine) {
        formatOptions.fieldSubqueryParensOnOwnLine = options.subqueryParensNewLine;
    }
    if (options.keywordsNewLine) {
        formatOptions.newLineAfterKeywords = options.keywordsNewLine;
    }
    let output = src_1.composeQuery(JSON.parse(query), { format: options.format, formatOptions });
    if (options.json) {
        console.log(JSON.stringify({ query: output }));
    }
    else {
        console.log(output);
    }
});
program
    .command('format <query>')
    .option('-i --indent <chars>', 'number of tab characters to indent', 1)
    .option('-m --line-length <chars>', 'max number of characters per lins', 60)
    .option('-s --subquery-parens-new-line', 'subquery parens on own line')
    .option('-k --keywords-new-line', 'new line after keywords')
    .option('-j, --json', 'output as JSON')
    .action((query, options) => {
    const formatOptions = {};
    if (options.indent) {
        formatOptions.numIndent = options.indent;
    }
    if (options.lineLength) {
        formatOptions.fieldMaxLineLength = options.lineLength;
    }
    if (options.subqueryParensNewLine) {
        formatOptions.fieldSubqueryParensOnOwnLine = options.subqueryParensNewLine;
    }
    if (options.keywordsNewLine) {
        formatOptions.newLineAfterKeywords = options.keywordsNewLine;
    }
    const output = src_1.formatQuery(query, formatOptions);
    if (options.json) {
        console.log(JSON.stringify({ query: output }));
    }
    else {
        console.log(output);
    }
});
program
    .command('valid <query>')
    .option('-j, --json', 'output as JSON')
    .action((query, options) => {
    const isValid = src_1.isQueryValid(query);
    if (options.json) {
        console.log(JSON.stringify({ isValid }));
    }
    else {
        if (isValid) {
            console.log('true');
        }
        else {
            console.error('false');
            process.exit(1);
        }
    }
});
program.parse(process.argv);
